summaryrefslogtreecommitdiffstats
path: root/languages/ruby/app_templates/kapp/app.rb
diff options
context:
space:
mode:
Diffstat (limited to 'languages/ruby/app_templates/kapp/app.rb')
-rw-r--r--languages/ruby/app_templates/kapp/app.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/languages/ruby/app_templates/kapp/app.rb b/languages/ruby/app_templates/kapp/app.rb
index 37a00d8b..af807fe9 100644
--- a/languages/ruby/app_templates/kapp/app.rb
+++ b/languages/ruby/app_templates/kapp/app.rb
@@ -181,13 +181,13 @@ class %{APPNAMESC} < KDE::MainWindow
if @printer.nil? then @printer = KDE::Printer.new end
if @printer.setup(self)
# setup the printer. with Qt, you always "print" to a
# Qt::Painter.. whether the output medium is a pixmap, a screen,
# or paper
- p = Qt::Painter.new
+ p = TQt::Painter.new
p.begin(@printer)
# we let our view do the actual printing
- metrics = Qt::PaintDeviceMetrics.new(@printer)
+ metrics = TQt::PaintDeviceMetrics.new(@printer)
@view.print(p, metrics.height(), metrics.width())
# and send the result to the printer
@@ -181,13 +181,13 @@ class %{APPNAMESC} < KDE::MainWindow
if @printer.setup(self)
# setup the printer. with Qt, you always "print" to a
- # Qt::Painter.. whether the output medium is a pixmap, a screen,
+ # TQt::Painter.. whether the output medium is a pixmap, a screen,
# or paper